% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/autoplot.R
\name{autoplot.ResamplingSpCVCoords}
\alias{autoplot.ResamplingSpCVCoords}
\alias{autoplot.ResamplingRepeatedSpCVCoords}
\alias{plot.ResamplingSpCVCoords}
\alias{plot.ResamplingRepeatedSpCVCoords}
\title{Visualization Functions for SpCV Coords Methods.}
\usage{
\method{autoplot}{ResamplingSpCVCoords}(
  object,
  task,
  fold_id = NULL,
  plot_as_grid = TRUE,
  train_color = "#0072B5",
  test_color = "#E18727",
  crs = NULL,
  ...
)

\method{autoplot}{ResamplingRepeatedSpCVCoords}(
  object,
  task,
  fold_id = NULL,
  repeats_id = NULL,
  plot_as_grid = TRUE,
  train_color = "#0072B5",
  test_color = "#E18727",
  crs = NULL,
  ...
)

\method{plot}{ResamplingSpCVCoords}(x, ...)

\method{plot}{ResamplingRepeatedSpCVCoords}(x, ...)
}
\arguments{
\item{object}{\verb{[Resampling]}\cr
mlr3 spatial resampling object of class \link{ResamplingSpCVCoords} or
\link{ResamplingRepeatedSpCVCoords}.}

\item{task}{\verb{[TaskClassifST]/[TaskRegrST]}\cr
mlr3 task object.}

\item{fold_id}{\verb{[numeric]}\cr
Fold IDs to plot.}

\item{plot_as_grid}{\verb{[logical(1)]}\cr
Should a gridded plot using via \CRANpkg{patchwork} be created? If \code{FALSE}
only a list with all \CRANpkg{ggplot2} resamplings is returned. Only applies
if a numeric vector is passed to argument \code{fold_id}.}

\item{train_color}{\verb{[character(1)]}\cr
The color to use for the training set observations.}

\item{test_color}{\verb{[character(1)]}\cr
The color to use for the test set observations.}

\item{crs}{\verb{[character]}\cr
EPSG code of the CRS for x and y axes.}

\item{...}{Not used.}

\item{repeats_id}{\verb{[numeric]}\cr
Repetition ID to plot.}

\item{x}{\verb{[Resampling]}\cr
mlr3 spatial resampling object of class \link{ResamplingSpCVCoords} or
\link{ResamplingRepeatedSpCVCoords}.}
}
\description{
Generic S3 \code{plot()} and \code{autoplot()} (ggplot2) methods.
}
\examples{
if (mlr3misc::require_namespaces(c("sf"), quietly = TRUE)) {
  library(mlr3)
  library(mlr3spatiotempcv)
  task = tsk("ecuador")
  resampling = rsmp("spcv_coords")
  resampling$instantiate(task)

  autoplot(resampling, task) +
    ggplot2::scale_x_continuous(breaks = seq(-79.085, -79.055, 0.01))
  autoplot(resampling, task, 1)
  autoplot(resampling, task, c(1, 2))
}
}
